@@ -268,16 +268,6 @@ class Acido(object):
         if not self.selected_instances:
             print(bad('You didn\'t select any containers to execute the command.'))
             return
-        
-        if input_cmd:
-            for cg, containers in self.instances_named.items():
-                if cg in self.selected_instances:
-                    for cont in containers:
-                        executed = True
-                        result = pool.apply_async(exec_command, 
-                                                (self.rg, cg, cont, 'pip install acido', max_retries), 
-                                                callback=instances_outputs)
-                        results.append(result)
 
         for cg, containers in self.instances_named.items():
             if cg in self.selected_instances:
@@ -371,4 +361,4 @@ if __name__ == "__main__":
     if args.remove:
         acido.rm(args.remove)
     if args.interactive:
-        code.interact(banner='acido 0.0.1', local=locals())
\ No newline at end of file
+        code.interact(banner=f'acido {__version__}', local=locals())
\ No newline at end of file
